===========================================
NYMMS (Not Your Mother's Monitoring System)
===========================================

You can find the latest docs (there aren't enough!) at ReadTheDocs_.

NYMMS is a monitoring framework that takes inspiration from a lot of different
places.

It's goals are:

- Independently scalable components
- Fault tolerant
- Easily useable in a cloud environment
- Easy to add new monitors

There are many other goals, but that's a good start.

Here's a somewhat hard to understand diagram (at least without some
explanation):

.. image:: https://raw.github.com/cloudtools/nymms/master/docs/_static/images/nymms_arch.png

Requirements
============

Currently the main requirements are:

- Python (2.7 - may work on older versions, haven't tested)
- boto
- PyYAML (used in a few backends, will eventually not be a requirement unless
  you need to use those backends)
- Jinja2 (needed for templating)

Optionally:

- pagerduty (0.2.1 https://pypi.python.org/pypi/pagerduty/0.2.1) if you use the
  pagerduty reactor handler

.. _`boto pull request`: https://github.com/boto/boto/pull/1414
.. _`ReadTheDocs`: http://nymms.readthedocs.org/en/latest/
